@@ -3,7 +3,6 @@ conda packages.
 """
 import os
 
-from wheel.util import native  # type: ignore
 from .tmpdirs import InTemporaryDirectory
 from .tools import tarbz2todir
 
@@ -31,4 +30,4 @@ class InCondaPkgCtx(InCondaPkg):
     def iter_files(self):
         files = os.path.join(self.path, 'info', 'files')
         with open(files) as f:
-            return [native(l.strip()) for l in f.readlines()]
+            return [line.strip() for line in f.readlines()]
